> **Warning:** This is a legacy branch and kept for compatibility and the lulz.
> Feel free to use it, it still works although its functionalities are limited.
> Switch to the `master` branch for the real deal.

### TODO
- [ ] unify db_manager return types
- [ ] weakdeps are not parsed from XML thus not working (not in db)
- [ ] arch other then x86_64 is still untested
- [ ] add cool banner on interactive mode
- [ ] when changing config options, query for auto-refresh of metadata (option 4+3)
